@@ -16,22 +16,15 @@ from .utils import (
 )
 
 __progname__ = 'antiseptic'
-__version__ = '0.1.1'
+__version__ = '0.1.2'
 __author__ = 'Naglis Jonaitis'
 __email__ = 'njonaitis@gmail.com'
 __description__ = 'A simple movie directory name cleaner'
 
-logging.basicConfig(level=logging.INFO)
 LOG = logging.getLogger(__name__)
-TEST_ERROR_TEMPLATE = '''
-ERROR: Rule: %s, test case #%d
------------------------------
-%s'''
-TEST_FAIL_TEMPLATE = '''
-FAIL: Rule: %s, test case #%d
------------------------------
-Input: %s
-Expected: %s, got: %s'''
+CONSOLE_MESSAGE_FORMAT = '%(message)s'
+LOG_FILE_MESSAGE_FORMAT = '[%(asctime)s] %(levelname)-8s %(name)s %(message)s'
+DEFAULT_VERBOSE_LEVEL = 1
 
 
 class Cleaner(object):
@@ -86,20 +79,10 @@ class Cleaner(object):
 
     @staticmethod
     def apply_rule(rule, text):
-        if rule.get('repeat', False):
-            changed = False
-            while True:
-                m = re.search(rule['rule'], text)
-                if not m:
-                    break
-                text = re.sub(rule['rule'], rule.get('sub', ''), text)
-                changed = True
-            return changed, text
-        else:
-            m = re.search(rule['rule'], text)
-            if m:
-                return True, re.sub(rule['rule'], rule.get('sub', ''), text)
-            return False, text
+        m = re.search(rule['rule'], text)
+        if m:
+            return True, re.sub(rule['rule'], rule.get('sub', ''), text)
+        return False, text
 
 
 def rename_dir(path, cleaner, preview=False, default_choice='n'):
@@ -205,51 +188,6 @@ def do_rename(args, config):
             args.path, c, preview=args.preview, default_choice=args.choice)
 
 
-def do_test(args, config):
-    c = Cleaner()
-    rules_filename = config['rules_filename']
-    try:
-        c.load_rules(rules_filename)
-    except OSError as e:
-        if e.errno == errno.ENOENT:
-            raise SystemExit('The rules file: %s does not exist. '
-                             'Run `%s update` to update the rules.' %
-                             (rules_filename, __file__))
-        else:
-            raise
-
-    count, fails, errors = 0, 0, 0
-    output = []
-    for rule in c.rules:
-        for i, (in_, out_) in enumerate(rule.get('tests', []), start=1):
-            count += 1
-            try:
-                _, result = Cleaner.apply_rule(rule, in_)
-            except Exception as e:
-                output.append(TEST_ERROR_TEMPLATE % (rule['id'], i, e))
-                sys.stderr.write('E')
-                errors += 1
-            else:
-                if result == out_:
-                    sys.stderr.write('.')
-                else:
-                    output.append(TEST_FAIL_TEMPLATE %
-                                  (rule['id'], i, in_, out_, result))
-                    sys.stderr.write('F')
-                    fails += 1
-            finally:
-                if count % 80 == 0:
-                    sys.stderr.write('\n')
-    for line in output:
-        print(line, file=sys.stderr)
-
-    print('\n\nTotal: %d (Failed: %d, Errors: %d)' % (count, fails, errors),
-          file=sys.stderr)
-
-    if fails + errors > 0:
-        sys.exit(1)
-
-
 def main():
     p = argparse.ArgumentParser(prog=__progname__, description=__description__)
     p.add_argument('--version', action='version',
@@ -257,6 +195,16 @@ def main():
     p.add_argument(
         '-d', '--debug', action='store_true',
         help='output debug information')
+    p.add_argument(
+        '-v', '--verbose', action='count', dest='verbose_level',
+        default=DEFAULT_VERBOSE_LEVEL,
+        help='increase verbosity of output. Can be repeated.',)
+    p.add_argument(
+        '--log-file', action='store', default=None,
+        help='specify a file to log output. Disabled by default.',)
+    p.add_argument(
+        '--quiet', action='store_const', dest='verbose_level',
+        const=0, help='suppress output except warnings and errors',)
     subparsers = p.add_subparsers()
 
     rename_parser = subparsers.add_parser('rename', help='rename directories')
@@ -280,17 +228,42 @@ def main():
         help='force update even if already on the latest version')
     update_parser.set_defaults(func=do_update)
 
-    test_parser = subparsers.add_parser('test', help='test rules')
-    test_parser.set_defaults(func=do_test)
-
     args = p.parse_args()
 
-    if args.debug:
-        LOG.setLevel(logging.DEBUG)
-    else:
-        LOG.setLevel(logging.INFO)
+    root_logger = logging.getLogger()
+    root_logger.setLevel(logging.DEBUG)
 
-    config = get_config()
+    # Set up logging to a file.
+    if args.log_file:
+        file_handler = logging.FileHandler(
+            filename=args.log_file,
+        )
+        formatter = logging.Formatter(LOG_FILE_MESSAGE_FORMAT)
+        file_handler.setFormatter(formatter)
+        root_logger.addHandler(file_handler)
 
-    if hasattr(args, 'func'):
-        getattr(args, 'func')(args, config)
+    # Always send higher-level messages to the console via stderr
+    console = logging.StreamHandler(sys.stderr)
+    console_level = {
+        0: logging.WARNING,
+        1: logging.INFO,
+        2: logging.DEBUG,
+    }.get(args.verbose_level, logging.DEBUG)
+    console.setLevel(console_level)
+    formatter = logging.Formatter(CONSOLE_MESSAGE_FORMAT)
+    console.setFormatter(formatter)
+    root_logger.addHandler(console)
+
+    try:
+        config = get_config()
+        if hasattr(args, 'func'):
+            getattr(args, 'func')(args, config)
+        else:
+            p.print_help()
+    except Exception as err:
+        if args.debug:
+            LOG.exception(err)
+            raise
+        else:
+            LOG.error(err)
+            return 1
